@@ -20,17 +20,16 @@ import argparse
 import collections
 import copy
 import functools
-import uuid
-
 
 import six
 from six.moves import range
 
 from oslo_log import log as logging
+from oslo_utils import uuidutils
 
 from congress.datalog import analysis
 from congress.datalog import base
-from congress.datalog.builtin import congressbuiltin
+from congress.datalog import builtin
 
 # set up appropriate antlr paths per python version and import runtime
 # import appropriate Lexer & Parser per python version
@@ -783,10 +782,10 @@ class Literal (object):
 
     def is_builtin(self, check_arguments=True):
         if check_arguments:
-            return congressbuiltin.builtin_registry.is_builtin(
+            return builtin.builtin_registry.is_builtin(
                 self.table, len(self.arguments))
         else:
-            return congressbuiltin.builtin_registry.is_builtin(
+            return builtin.builtin_registry.is_builtin(
                 self.table)
 
     def tablename(self, default_service=None):
@@ -917,7 +916,7 @@ class Rule(object):
         self.body = body
         self.location = location
         self._hash = None
-        self.id = id or uuid.uuid4()
+        self.id = id or uuidutils.generate_uuid()
         self.name = name
         self.comment = comment
         self.original_str = original_str
@@ -1509,8 +1508,8 @@ def reorder_for_safety(rule):
         if lit.is_negated():
             target_vars = lit.variable_names()
         elif lit.is_builtin():
-            builtin = congressbuiltin.builtin_registry.builtin(lit.table)
-            target_vars = lit.arguments[0:builtin.num_inputs]
+            built = builtin.builtin_registry.builtin(lit.table)
+            target_vars = lit.arguments[0:built.num_inputs]
             target_vars = set([x.name for x in target_vars if x.is_variable()])
         else:
             # neither a builtin nor negated
@@ -2253,6 +2252,17 @@ def print_tree(tree, text, kids, ind=0):
             print_tree(child, text, kids, ind + 1)
 
 
+def string_is_servicename(name):
+    """Returns True if @name can be a servicename in the policy language."""
+    if name == "builtin":   # 'builtin' is reserved for builtins
+        return False
+    try:
+        rules = parse("p :- %s:q()" % name)
+        return len(rules) == 1
+    except exception.PolicyException:
+        return False
+
+
 ##############################################################################
 # Mains
 ##############################################################################
