@@ -12,18 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
+
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
 import cinderclient.client
 
+from congress.datasources import constants
 from congress.datasources import datasource_driver
 from congress.datasources import datasource_utils as ds_utils
 
 
-def d6service(name, keys, inbox, datapath, args):
-    """This method is called by d6cage to create a dataservice instance."""
-    return CinderDriver(name, keys, inbox, datapath, args)
-
-
-class CinderDriver(datasource_driver.DataSourceDriver,
+class CinderDriver(datasource_driver.PollingDataSourceDriver,
                    datasource_driver.ExecutionDriver):
     VOLUMES = "volumes"
     SNAPSHOTS = "snapshots"
@@ -75,12 +76,15 @@ class CinderDriver(datasource_driver.DataSourceDriver,
     TRANSLATORS = [volumes_translator, snapshots_translator,
                    services_translator]
 
-    def __init__(self, name='', keys='', inbox=None, datapath=None, args=None):
-        super(CinderDriver, self).__init__(name, keys, inbox, datapath, args)
+    def __init__(self, name='', args=None):
+        super(CinderDriver, self).__init__(name, args=args)
         datasource_driver.ExecutionDriver.__init__(self)
-        self.creds = self.get_cinder_credentials_v2(args)
-        self.cinder_client = cinderclient.client.Client(**self.creds)
-        self.inspect_builtin_methods(self.cinder_client, 'cinderclient.v2.')
+        session = ds_utils.get_keystone_session(args)
+        self.cinder_client = cinderclient.client.Client(version='2',
+                                                        session=session)
+        self.add_executable_client_methods(self.cinder_client,
+                                           'cinderclient.v2.')
+        self.initialize_update_method()
         self._init_end_start_poll()
 
     @staticmethod
@@ -90,30 +94,24 @@ class CinderDriver(datasource_driver.DataSourceDriver,
         result['description'] = ('Datasource driver that interfaces with '
                                  'OpenStack cinder.')
         result['config'] = ds_utils.get_openstack_required_config()
+        result['config']['lazy_tables'] = constants.OPTIONAL
         result['secret'] = ['password']
         return result
 
-    def update_from_datasource(self):
-        volumes = self.cinder_client.volumes.list(
-            detailed=True, search_opts={"all_tenants": 1})
-        self._translate_volumes(volumes)
+    def initialize_update_method(self):
+        volumes_method = lambda: self._translate_volumes(
+            self.cinder_client.volumes.list(detailed=True,
+                                            search_opts={'all_tenants': 1}))
+        self.add_update_method(volumes_method, self.volumes_translator)
 
-        snapshots = self.cinder_client.volume_snapshots.list(
-            detailed=True, search_opts={"all_tenants": 1})
-        self._translate_snapshots(snapshots)
+        snapshots_method = lambda: self._translate_snapshots(
+            self.cinder_client.volume_snapshots.list(
+                detailed=True, search_opts={'all_tenants': 1}))
+        self.add_update_method(snapshots_method, self.snapshots_translator)
 
-        services = self.cinder_client.services.list(
-            host=None, binary=None)
-        self._translate_services(services)
-
-    def get_cinder_credentials_v2(self, creds):
-        d = {}
-        d['version'] = '2'
-        d['username'] = creds['username']
-        d['api_key'] = creds['password']
-        d['auth_url'] = creds['auth_url']
-        d['project_id'] = creds['tenant_name']
-        return d
+        services_method = lambda: self._translate_services(
+            self.cinder_client.services.list(host=None, binary=None))
+        self.add_update_method(services_method, self.services_translator)
 
     @ds_utils.update_state_on_changed(VOLUMES)
     def _translate_volumes(self, obj):
