@@ -151,7 +151,7 @@ class DataService(object):
             service_id=self.service_id,
             node_id=self.node.node_id if self.node else None,
             published_tables=None,
-            subscribed_tables=None,
+            subscribed_tables=self._published_tables_with_subscriber,
             rpc_endpoints_info=None,
             )
 
@@ -448,11 +448,9 @@ class DataService(object):
     def subscriber_list(self):
         """Method that returns subscribers list.
 
-        This feature is duplicated in the distributed architecture. So the
-        method is defined only for backward compatibility.
+        It returns list of services subscribed to this service data.
         """
-        LOG.info('subscriber_list is duplicated in the new architecture.')
-        return []
+        return self.node.get_subscribers(self.service_id)
 
     def get_last_published_data_with_seqnum(self, table):
         """Method that returns the current seqnum & data for given table."""
