@@ -15,15 +15,12 @@
 
 import json
 import six
-import uuid
+
 
 import eventlet
 eventlet.monkey_patch()  # for using oslo.messaging w/ eventlet executor
 
-from futurist import periodics
-from oslo_concurrency import lockutils
 from oslo_config import cfg
-from oslo_db import exception as db_exc
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_messaging import exceptions as messaging_exceptions
@@ -32,38 +29,16 @@ from oslo_utils import importutils
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 
+from congress.datalog import compile as datalog_compile
 from congress.datasources import constants
 from congress.db import datasources as datasources_db
 from congress.dse2 import control_bus
-from congress.dse2 import data_service
 from congress import exception
 
 
 LOG = logging.getLogger(__name__)
 
 
-_dse_opts = [
-    cfg.StrOpt('bus_id', default='bus',
-               help='Unique ID of this DSE bus'),
-    cfg.IntOpt('ping_timeout', default=5,
-               help='RPC short timeout in seconds; used to ping destination'),
-    cfg.IntOpt('long_timeout', default=120,
-               help='RPC long timeout in seconds; used on potentially long '
-                    'running requests such as datasource action and PE row '
-                    'query'),
-    cfg.IntOpt('time_to_resub', default=10,
-               help='Time in seconds which a subscriber will wait for missing '
-                    'update before attempting to resubscribe from publisher'),
-    cfg.BoolOpt('execute_action_retry', default=False,
-                help='Set the flag to True to make Congress retry execute '
-                     'actions; may cause duplicate executions.'),
-    cfg.IntOpt('execute_action_retry_timeout', default=600,
-               help='The number of seconds to retry execute action before '
-                    'giving up. Zero or negative value means never give up.'),
-]
-cfg.CONF.register_opts(_dse_opts, group='dse')
-
-
 class DseNode(object):
     """Addressable entity participating on the DSE message bus.
 
@@ -122,7 +97,8 @@ class DseNode(object):
         self.node_rpc_endpoints.append(DseNodeEndpoints(self))
         self._running = False
         self._services = []
-        self.instance = uuid.uuid4()  # uuid to help recognize node_id clash
+        # uuid to help recognize node_id clash
+        self.instance = uuidutils.generate_uuid()
         # TODO(dse2): add detection and logging/rectifying for node_id clash?
         self.context = self._message_context()
         self.transport = messaging.get_transport(
@@ -258,7 +234,6 @@ class DseNode(object):
             return
 
         LOG.info("Stopping DSE node '%s'", self.node_id)
-        self.stop_datasource_synchronizer()
         for s in self._services:
             s.stop()
         self._rpc_server.stop()
@@ -484,6 +459,20 @@ class DseNode(object):
                         result[publisher] = set([table])
         return result
 
+    def get_subscribers(self, service_id):
+        """List of services subscribed to this service."""
+
+        result = set()
+        tables = self.subscriptions.get(service_id, None)
+        if not tables:
+            # no subscribers
+            return []
+
+        for t in tables:
+            result = result | self.subscriptions[service_id][t]
+
+        return list(result)
+
     def to_set_of_tuples(self, snapshot):
         try:
             return set([tuple(x) for x in snapshot])
@@ -543,10 +532,10 @@ class DseNode(object):
             result[driver['id']] = driver
         return result
 
-    def get_driver_info(self, driver):
-        driver = self.loaded_drivers.get(driver)
+    def get_driver_info(self, driver_name):
+        driver = self.loaded_drivers.get(driver_name)
         if not driver:
-            raise exception.DriverNotFound(id=driver)
+            raise exception.DriverNotFound(id=driver_name)
         return driver
 
     def get_drivers_info(self):
@@ -589,109 +578,17 @@ class DseNode(object):
             results.append(result)
         return results
 
-    # TODO(ekcs): should we start and stop these along with self.{start, stop}?
-    def start_periodic_tasks(self):
-        callables = [(self.synchronize, None, {}),
-                     (self._check_resub_all, None, {})]
-        self.periodic_tasks = periodics.PeriodicWorker(callables)
-        if self._running:
-            self.sync_thread = eventlet.spawn_n(self.periodic_tasks.start)
-
-    def stop_datasource_synchronizer(self):
-        if self.periodic_tasks:
-            self.periodic_tasks.stop()
-            self.periodic_tasks.wait()
-            self.periodic_tasks = None
-        if self.sync_thread:
-            eventlet.greenthread.kill(self.sync_thread)
-            self.sync_thread = None
-
-    @periodics.periodic(spacing=cfg.CONF.datasource_sync_period)
-    def synchronize(self):
-        try:
-            self.synchronize_datasources()
-        except Exception:
-            LOG.exception("synchronize_datasources failed")
-
-    @lockutils.synchronized('congress_synchronize_datasources')
-    def synchronize_datasources(self):
-        if not cfg.CONF.datasources:
-            LOG.debug("Skipping datasource synchronization on a "
-                      "non-datasources node")
-            return
-        LOG.info("Synchronizing running datasources")
-        added = 0
-        removed = 0
-        datasources = self.get_datasources(filter_secret=False)
-        db_datasources = []
-        # Look for datasources in the db, but not in the services.
-        for configured_ds in datasources:
-            db_datasources.append(configured_ds['id'])
-            active_ds = self.service_object(uuid_=configured_ds['id'])
-            # If datasource is not enabled, unregister the service
-            if not configured_ds['enabled']:
-                if active_ds:
-                    LOG.debug("unregistering %s service, datasource disabled "
-                              "in DB.", active_ds.service_id)
-                    self.unregister_service(active_ds.service_id)
-                    removed = removed + 1
-                continue
-            if active_ds is None:
-                # service is not up, create the service
-                LOG.info("registering %s service on node %s",
-                         configured_ds['name'], self.node_id)
-                service = self.create_datasource_service(configured_ds)
-                self.register_service(service)
-                added = added + 1
-
-        # Unregister the services which are not in DB
-        active_ds_services = [s for s in self._services
-                              if getattr(s, 'type', '') == 'datasource_driver']
-        db_datasources_set = set(db_datasources)
-        stale_services = [s for s in active_ds_services
-                          if s.ds_id not in db_datasources_set]
-        for s in stale_services:
-            LOG.debug("unregistering %s service, datasource not found in DB ",
-                      s.service_id)
-            self.unregister_service(uuid_=s.ds_id)
-            removed = removed + 1
-
-        LOG.info("synchronize_datasources, added %d removed %d on node %s",
-                 added, removed, self.node_id)
-
-        # This might be required once we support update datasource config
-
-        # if not self._config_eq(configured_ds, active_ds):
-        #    LOG.debug('configured and active disagree: %s %s',
-        #              strutils.mask_password(active_ds),
-        #              strutils.mask_password(configured_ds))
-
-        #    LOG.info('Reloading datasource: %s',
-        #             strutils.mask_password(configured_ds))
-        #    self.delete_datasource(configured_ds['name'],
-        #                           update_db=False)
-        #    self.add_datasource(configured_ds, update_db=False)
-
-    # def _config_eq(self, db_config, active_config):
-    #     return (db_config['name'] == active_config.service_id and
-    #             db_config['config'] == active_config.service_info['args'])
-
-    @periodics.periodic(spacing=cfg.CONF.dse.time_to_resub)
-    def _check_resub_all(self):
-        for s in self._services:
-            s.check_resub_all()
-
     def delete_missing_driver_datasources(self):
         removed = 0
         for datasource in datasources_db.get_datasources():
             try:
                 self.get_driver_info(datasource.driver)
             except exception.DriverNotFound:
-                ds_dict = self.make_datasource_dict(datasource)
-                self.delete_datasource(ds_dict)
+                datasources_db.delete_datasource_with_data(datasource.id)
                 removed = removed+1
-                LOG.debug("Deleted datasource with config %s ",
-                          strutils.mask_password(ds_dict))
+                LOG.debug("Datasource driver '%s' not found, deleting the "
+                          "datasource '%s' from DB ", datasource.driver,
+                          datasource.name)
 
         LOG.info("Datsource cleanup completed, removed %d datasources",
                  removed)
@@ -718,61 +615,10 @@ class DseNode(object):
                          if key in fields))
         return resource
 
-    # Note(thread-safety): blocking function
-    def add_datasource(self, item, deleted=False, update_db=True):
-        req = self.make_datasource_dict(item)
-
-        # check the request has valid information
-        self.validate_create_datasource(req)
-        if self.is_valid_service(req['name']):
-            raise exception.DatasourceNameInUse(value=req['name'])
-
-        new_id = req['id']
-        LOG.debug("adding datasource %s", req['name'])
-        if update_db:
-            LOG.debug("updating db")
-            try:
-                # Note(thread-safety): blocking call
-                datasource = datasources_db.add_datasource(
-                    id_=req['id'],
-                    name=req['name'],
-                    driver=req['driver'],
-                    config=req['config'],
-                    description=req['description'],
-                    enabled=req['enabled'])
-            except db_exc.DBDuplicateEntry:
-                raise exception.DatasourceNameInUse(value=req['name'])
-            except db_exc.DBError:
-                LOG.exception('Creating a new datasource failed.')
-                raise exception.DatasourceCreationError(value=req['name'])
-
-        new_id = datasource['id']
-        try:
-            self.synchronize_datasources()
-            # immediate synch policies on local PE if present
-            # otherwise wait for regularly scheduled synch
-            # TODO(dse2): use finer-grained method to synch specific policies
-            engine = self.service_object('engine')
-            if engine is not None:
-                engine.synchronize_policies()
-            # TODO(dse2): also broadcast to all PE nodes to synch
-        except exception.DataServiceError:
-            LOG.exception('the datasource service is already'
-                          'created in the node')
-        except Exception:
-            LOG.exception(
-                'Unexpected exception encountered while registering '
-                'new datasource %s.', req['name'])
-            if update_db:
-                datasources_db.delete_datasource(req['id'])
-            msg = ("Datasource service: %s creation fails." % req['name'])
-            raise exception.DatasourceCreationError(message=msg)
-
-        new_item = dict(item)
-        new_item['id'] = new_id
-        return self.make_datasource_dict(new_item)
-
     def validate_create_datasource(self, req):
+        name = req['name']
+        if not datalog_compile.string_is_servicename(name):
+            raise exception.InvalidDatasourceName(value=name)
         driver = req['driver']
         config = req['config'] or {}
         for loaded_driver in self.loaded_drivers.values():
@@ -847,25 +693,6 @@ class DseNode(object):
             raise exception.DataServiceError(msg % class_path)
         return service
 
-    # Note(thread-safety): blocking function
-    def delete_datasource(self, datasource, update_db=True):
-        LOG.debug("Deleting %s datasource ", datasource['name'])
-        datasource_id = datasource['id']
-        if update_db:
-            # Note(thread-safety): blocking call
-            result = datasources_db.delete_datasource_with_data(datasource_id)
-            if not result:
-                raise exception.DatasourceNotFound(id=datasource_id)
-
-        # Note(thread-safety): blocking call
-        try:
-            self.synchronize_datasources()
-        except Exception:
-            msg = ('failed to synchronize_datasource after '
-                   'deleting datasource: %s' % datasource_id)
-            LOG.exception(msg)
-            raise exception.DataServiceError(msg)
-
 
 class DseNodeEndpoints (object):
     """Collection of RPC endpoints that the DseNode exposes on the bus.
@@ -898,25 +725,3 @@ class DseNodeEndpoints (object):
             self.node.service_object(s).receive_data_sequenced(
                 publisher=publisher, table=table, data=data, seqnum=seqnum,
                 is_snapshot=is_snapshot)
-
-
-DS_MANAGER_SERVICE_ID = '_ds_manager'
-
-
-class DSManagerService(data_service.DataService):
-    """A proxy service to datasource managing methods in dse_node."""
-    def __init__(self, service_id):
-        super(DSManagerService, self).__init__(DS_MANAGER_SERVICE_ID)
-        self.add_rpc_endpoint(DSManagerEndpoints(self))
-
-
-class DSManagerEndpoints(object):
-
-    def __init__(self, service):
-        self.service = service
-
-    def add_datasource(self, context, items):
-        return self.service.node.add_datasource(items)
-
-    def delete_datasource(self, context, datasource):
-        return self.service.node.delete_datasource(datasource)
