@@ -17,18 +17,14 @@ from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
 
-import copy
-import os
-import os.path
-import re
 import sys
 
 from oslo_config import cfg
-
 from oslo_log import log as logging
 
 from congress.api import action_model
 from congress.api import application
+from congress.api import base as api_base
 from congress.api import datasource_model
 from congress.api import policy_model
 from congress.api import router
@@ -39,13 +35,13 @@ from congress.api import status_model
 from congress.api.system import driver_model
 from congress.api import table_model
 from congress.db import datasources as db_datasources
+from congress.dse2 import datasource_manager as ds_manager
 from congress.dse2 import dse_node
 from congress import exception
 from congress.policy_engines import agnostic
 
 
 LOG = logging.getLogger(__name__)
-ENGINE_SERVICE_NAME = 'engine'
 
 
 def create2(node_id=None, bus_id=None, existing_node=None,
@@ -75,37 +71,22 @@ def create2(node_id=None, bus_id=None, existing_node=None,
 
     # create services as required
     services = {}
+
     if datasources:
         LOG.info("Registering congress datasource services on node %s",
                  node.node_id)
         services['datasources'] = create_datasources(node)
-
-        # datasource policies would be created by respective PE's synchronizer
-        # for ds in services['datasources']:
-        #    try:
-        #        utils.create_datasource_policy(ds, ds.name,
-        #                                       ENGINE_SERVICE_NAME)
-        #    except (exception.BadConfig,
-        #            exception.DatasourceNameInUse,
-        #            exception.DriverNotFound,
-        #            exception.DatasourceCreationError) as e:
-        #        LOG.exception("Datasource %s creation failed. %s" % (ds, e))
-        #        node.unregister_service(ds)
+        services['ds_manager'] = ds_manager.DSManagerService(
+            api_base.DS_MANAGER_SERVICE_ID)
+        node.register_service(services['ds_manager'])
 
     if policy_engine:
         LOG.info("Registering congress PolicyEngine service on node %s",
                  node.node_id)
-        services[ENGINE_SERVICE_NAME] = create_policy_engine()
-        node.register_service(services[ENGINE_SERVICE_NAME])
-        initialize_policy_engine(services[ENGINE_SERVICE_NAME])
-
-    # start synchronizer and other periodic tasks
-    if policy_engine:
-        services[ENGINE_SERVICE_NAME].start_policy_synchronizer()
-    if datasources:
-        node.start_periodic_tasks()
-        node.register_service(
-            dse_node.DSManagerService(dse_node.DS_MANAGER_SERVICE_ID))
+        engine = create_policy_engine()
+        services[api_base.ENGINE_SERVICE_ID] = engine
+        node.register_service(engine)
+        initialize_policy_engine(engine)
 
     if api:
         LOG.info("Registering congress API service on node %s", node.node_id)
@@ -143,7 +124,7 @@ def create_api_models(bus):
 
 def create_policy_engine():
     """Create policy engine and initialize it using the api models."""
-    engine = agnostic.DseRuntime(ENGINE_SERVICE_NAME)
+    engine = agnostic.DseRuntime(api_base.ENGINE_SERVICE_ID)
     engine.debug_mode()  # should take this out for production
     return engine
 
@@ -178,37 +159,7 @@ def create_datasources(bus):
                           "clean up stale datasources in DB.")
             sys.exit(1)
         except Exception:
-            LOG.exception("datasource %s creation failed. %s service may not "
-                          "be running.", ds.name, ds.driver)
+            LOG.exception("datasource %s creation failed.", ds.name)
+            raise
+
     return services
-
-
-def load_data_service(service_name, config, cage, rootdir, id_):
-    """Load service.
-
-    Load a service if not already loaded. Also loads its
-    module if the module is not already loaded.  Returns None.
-    SERVICE_NAME: name of service
-    CONFIG: dictionary of configuration values
-    CAGE: instance to load service into
-    ROOTDIR: dir for start of module paths
-    ID: UUID of the service.
-    """
-    config = copy.copy(config)
-    if service_name in cage.services:
-        return
-    if 'module' not in config:
-        raise exception.DataSourceConfigException(
-            "Service %s config missing 'module' entry" % service_name)
-    module_path = config['module']
-    module_name = re.sub('[^a-zA-Z0-9_]', '_', module_path)
-    if not os.path.isabs(module_path) and rootdir is not None:
-        module_path = os.path.join(rootdir, module_path)
-    if module_name not in sys.modules:
-        LOG.info("Trying to create module %s from %s",
-                 module_name, module_path)
-        cage.loadModule(module_name, module_path)
-    LOG.info("Trying to create service %s with module %s",
-             service_name, module_name)
-    cage.createservice(name=service_name, moduleName=module_name,
-                       args=config, type_='datasource_driver', id_=id_)
