@@ -37,13 +37,13 @@ class TestDatasourceModel(base.SqlTestCase):
         self.data = services['data']
         self.node = services['node']
         self.engine = services['engine']
+        self.ds_manager = services['ds_manager']
         self.datasource = self._get_datasource_request()
-        self.node.add_datasource(self.datasource)
+        self.ds_manager.add_datasource(self.datasource)
 
     def tearDown(self):
         super(TestDatasourceModel, self).tearDown()
         self.node.stop()
-        self.node.start()
 
     def _get_datasource_request(self):
         # leave ID out--generated during creation
@@ -62,7 +62,7 @@ class TestDatasourceModel(base.SqlTestCase):
         self.assertEqual(1, len(dinfo))
         datasource2 = self._get_datasource_request()
         datasource2['name'] = 'datasource2'
-        self.node.add_datasource(datasource2)
+        self.ds_manager.add_datasource(datasource2)
         dinfo = self.datasource_model.get_items(None)['results']
         self.assertEqual(2, len(dinfo))
         del dinfo[0]['id']
@@ -70,13 +70,12 @@ class TestDatasourceModel(base.SqlTestCase):
 
     def test_add_item(self):
         datasource3 = self._get_datasource_request()
-        datasource3['name'] = 'datasource-test-3'
+        datasource3['name'] = 'datasource_test_3'
         self.datasource_model.add_item(datasource3, {})
-        ds_obj = self.node.service_object('datasource-test-3')
-        self.engine.synchronize_policies()
-        obj = self.engine.policy_object('datasource-test-3')
+        ds_obj = self.node.service_object('datasource_test_3')
+        obj = self.engine.policy_object('datasource_test_3')
         self.assertIsNotNone(obj.schema)
-        self.assertEqual('datasource-test-3', obj.name)
+        self.assertEqual('datasource_test_3', obj.name)
         self.assertIsNotNone(ds_obj)
 
     def test_add_item_duplicate(self):
@@ -84,19 +83,24 @@ class TestDatasourceModel(base.SqlTestCase):
                           self.datasource_model.add_item,
                           self.datasource, {})
 
+    def test_add_item_invalid_tablename(self):
+        datasource = self._get_datasource_request()
+        datasource['name'] = "invalid-table-name"
+        self.assertRaises(webservice.DataModelException,
+                          self.datasource_model.add_item,
+                          datasource, {})
+
     def test_delete_item(self):
         datasource = self._get_datasource_request()
-        datasource['name'] = 'test-datasource'
+        datasource['name'] = 'test_datasource'
         d_id, dinfo = self.datasource_model.add_item(datasource, {})
-        self.engine.synchronize_policies()
-        self.assertTrue(self.engine.assert_policy_exists('test-datasource'))
+        self.assertTrue(self.engine.assert_policy_exists('test_datasource'))
         context = {'ds_id': d_id}
         self.datasource_model.delete_item(None, {}, context=context)
-        ds_obj = self.node.service_object('test-datasource')
+        ds_obj = self.node.service_object('test_datasource')
         self.assertIsNone(ds_obj)
-        self.engine.synchronize_policies()
         self.assertRaises(exception.PolicyRuntimeException,
-                          self.engine.assert_policy_exists, 'test-datasource')
+                          self.engine.assert_policy_exists, 'test_datasource')
         self.assertRaises(exception.DatasourceNotFound,
                           self.node.get_datasource, d_id)
 
@@ -129,10 +133,10 @@ class TestDatasourceModel(base.SqlTestCase):
         nova_client = NovaClient("testing")
         args = helper.datasource_openstack_args()
         nova = nova_driver.NovaDriver('nova', args=args)
-        self.node.register_service(nova)
+        nova.nova_client = nova_client
         nova.update_from_datasource = mock.MagicMock()
         nova._execute_api = _execute_api
-        nova.nova_client = nova_client
+        self.node.register_service(nova)
 
         execute_action = self.datasource_model.execute_action
 
