@@ -13,14 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
 import mock
-from oslo_config import cfg
 from oslo_utils import uuidutils
 
 from congress.api import error_codes
-from congress.api import policy_model
 from congress.api import webservice
-from congress import harness
+from congress.tests.api import base as api_base
 from congress.tests import base
 from congress.tests import helper
 
@@ -28,41 +30,32 @@ from congress.tests import helper
 class TestPolicyModel(base.SqlTestCase):
     def setUp(self):
         super(TestPolicyModel, self).setUp()
-        # Here we load the fake driver
-        cfg.CONF.set_override(
-            'drivers',
-            ['congress.tests.fake_datasource.FakeDataSource'])
-
-        self.cage = harness.create(helper.root_path())
-        self.engine = self.cage.service_object('engine')
-        self.rule_api = self.cage.service_object('api-rule')
-        self.policy_model = policy_model.PolicyModel("policy_model", {},
-                                                     policy_engine=self.engine)
 
+        services = api_base.setup_config()
+        self.policy_model = services['api']['api-policy']
+        self.rule_api = services['api']['api-rule']
+        self.node = services['node']
+        self.engine = services['engine']
+        self.initial_policies = set(self.engine.policy_names())
         self._add_test_policy()
 
-    def tearDown(self):
-        super(TestPolicyModel, self).tearDown()
-
     def _add_test_policy(self):
         test_policy = {
-            "name": "test-policy",
+            "name": "test_policy",
             "description": "test policy description",
             "kind": "nonrecursive",
             "abbreviation": "abbr"
         }
-
         test_policy_id, obj = self.policy_model.add_item(test_policy, {})
         test_policy["id"] = test_policy_id
         test_policy["owner_id"] = obj["owner_id"]
 
         test_policy2 = {
-            "name": "test-policy2",
+            "name": "test_policy2",
             "description": "test policy2 description",
             "kind": "nonrecursive",
             "abbreviation": "abbr2"
         }
-
         test_policy_id, obj = self.policy_model.add_item(test_policy2, {})
         test_policy2["id"] = test_policy_id
         test_policy2["owner_id"] = obj["owner_id"]
@@ -70,6 +63,17 @@ class TestPolicyModel(base.SqlTestCase):
         self.policy = test_policy
         self.policy2 = test_policy2
 
+        action_policy = self.policy_model.get_item('action', {})
+        self.action_policy = action_policy
+
+    def test_in_mem_and_db_policies(self):
+        ret = self.policy_model.get_items({})
+        db = [p['name'] for p in ret['results']]
+        mem = self.engine.policy_names()
+        new_memory = set(mem) - self.initial_policies
+        new_db = set(db) - self.initial_policies
+        self.assertEqual(new_memory, new_db)
+
     def test_get_items(self):
         ret = self.policy_model.get_items({})
         self.assertTrue(all(p in ret['results']
@@ -81,9 +85,10 @@ class TestPolicyModel(base.SqlTestCase):
         self.assertEqual(expected_ret, ret)
 
     def test_get_invalid_item(self):
-        expected_ret = None
-        ret = self.policy_model.get_item('invalid-id', {})
-        self.assertEqual(expected_ret, ret)
+        self.assertRaisesRegexp(webservice.DataModelException,
+                                '^Not Found',
+                                self.policy_model.get_item,
+                                'invalid-id', {})
 
     @mock.patch('oslo_utils.uuidutils.generate_uuid')
     def test_add_item(self, patched_gen_uuid):
@@ -150,21 +155,23 @@ class TestPolicyModel(base.SqlTestCase):
 
     def test_delete_item(self):
         expected_ret = self.policy
+        policy_id = self.policy['id']
 
-        ret = self.policy_model.delete_item(self.policy['id'], {})
+        ret = self.policy_model.delete_item(policy_id, {})
         self.assertEqual(expected_ret, ret)
+        self.assertRaisesRegexp(webservice.DataModelException,
+                                '^Not Found',
+                                self.policy_model.get_item,
+                                self.policy['id'], {})
 
-        expected_ret = None
-        ret = self.policy_model.get_item(self.policy['id'], {})
-        self.assertEqual(expected_ret, ret)
-
-    def test_delete_item_invalid_id(self):
-        self.assertRaises(KeyError,
-                          self.policy_model.delete_item, 'invalid-id', {})
+        # check that deleting the policy also deletes the rules
+        self.assertRaises(webservice.DataModelException,
+                          self.rule_api.get_items,
+                          {}, {'policy_id': policy_id})
 
     def test_simulate_action(self):
         context = {
-            'policy_id': self.engine.ACTION_THEORY
+            'policy_id': self.action_policy['name']
         }
         action_rule1 = {
             'rule': 'action("q")',
@@ -177,7 +184,7 @@ class TestPolicyModel(base.SqlTestCase):
 
         request_body = {
             'query': 'p(x)',
-            'action_policy': self.engine.ACTION_THEORY,
+            'action_policy': self.action_policy['name'],
             'sequence': 'q(1)'
         }
         request = helper.FakeRequest(request_body)
@@ -192,7 +199,7 @@ class TestPolicyModel(base.SqlTestCase):
 
     def test_simulate_with_delta(self):
         context = {
-            'policy_id': self.engine.ACTION_THEORY
+            'policy_id': self.action_policy['name']
         }
         action_rule1 = {
             'rule': 'action("q")',
@@ -205,7 +212,7 @@ class TestPolicyModel(base.SqlTestCase):
 
         request_body = {
             'query': 'p(x)',
-            'action_policy': self.engine.ACTION_THEORY,
+            'action_policy': self.action_policy['name'],
             'sequence': 'q(1)'
         }
         request = helper.FakeRequest(request_body)
@@ -223,7 +230,7 @@ class TestPolicyModel(base.SqlTestCase):
 
     def test_simulate_with_trace(self):
         context = {
-            'policy_id': self.engine.ACTION_THEORY
+            'policy_id': self.action_policy['name']
         }
         action_rule1 = {
             'rule': 'action("q")',
@@ -236,7 +243,7 @@ class TestPolicyModel(base.SqlTestCase):
 
         request_body = {
             'query': 'p(x)',
-            'action_policy': self.engine.ACTION_THEORY,
+            'action_policy': self.action_policy['name'],
             'sequence': 'q(1)'
         }
         request = helper.FakeRequest(request_body)
@@ -254,7 +261,43 @@ class TestPolicyModel(base.SqlTestCase):
         # check response's keys equal expected_ret's key
         self.assertTrue(all(key in expected_ret.keys() for key in ret.keys()))
         self.assertEqual(expected_ret['result'], ret['result'])
-        self.assertTrue(ret['trace'] > 10)
+        self.assertTrue(len(ret['trace']) > 10)
+
+    def test_simulate_with_delta_and_trace(self):
+        context = {
+            'policy_id': self.action_policy['name']
+        }
+        action_rule1 = {
+            'rule': 'action("q")',
+        }
+        action_rule2 = {
+            'rule': 'p+(x):- q(x)'
+        }
+        self.rule_api.add_item(action_rule1, {}, context=context)
+        self.rule_api.add_item(action_rule2, {}, context=context)
+
+        request_body = {
+            'query': 'p(x)',
+            'action_policy': self.action_policy['name'],
+            'sequence': 'q(1)'
+        }
+        request = helper.FakeRequest(request_body)
+        params = {
+            'trace': 'true',
+            'delta': 'true'
+        }
+        expected_ret = {
+            'result': [
+                "p+(1)"
+            ],
+            'trace': "trace strings"
+        }
+
+        ret = self.policy_model.simulate_action(params, context, request)
+        # check response's keys equal expected_ret's key
+        self.assertTrue(all(key in expected_ret.keys() for key in ret.keys()))
+        self.assertEqual(expected_ret['result'], ret['result'])
+        self.assertTrue(len(ret['trace']) > 10)
 
     def test_simulate_invalid_policy(self):
         context = {
@@ -262,7 +305,7 @@ class TestPolicyModel(base.SqlTestCase):
         }
         request_body = {
             'query': 'p(x)',
-            'action_policy': self.engine.ACTION_THEORY,
+            'action_policy': self.action_policy['name'],
             'sequence': 'q(1)'
         }
         request = helper.FakeRequest(request_body)
@@ -273,7 +316,7 @@ class TestPolicyModel(base.SqlTestCase):
 
     def test_simulate_invalid_sequence(self):
         context = {
-            'policy_id': self.engine.ACTION_THEORY
+            'policy_id': self.action_policy['name']
         }
         action_rule = {
             'rule': 'w(x):-z(x)',
@@ -282,7 +325,7 @@ class TestPolicyModel(base.SqlTestCase):
 
         request_body = {
             'query': 'w(x)',
-            'action_policy': self.engine.ACTION_THEORY,
+            'action_policy': self.action_policy['name'],
             'sequence': 'z(1)'
         }
         request = helper.FakeRequest(request_body)
@@ -290,3 +333,96 @@ class TestPolicyModel(base.SqlTestCase):
         self.assertRaises(webservice.DataModelException,
                           self.policy_model.simulate_action,
                           {}, context, request)
+
+    def test_simulate_policy_errors(self):
+        def check_err(params, context, request, emsg):
+            try:
+                self.policy_model.simulate_action(params, context, request)
+                self.assertFail()
+            except webservice.DataModelException as e:
+                self.assertIn(emsg, str(e))
+
+        context = {
+            'policy_id': self.action_policy['name']
+        }
+
+        # Missing query
+        body = {'action_policy': self.action_policy['name'],
+                'sequence': 'q(1)'}
+        check_err({}, context, helper.FakeRequest(body),
+                  'Simulate requires parameters')
+
+        # Invalid query
+        body = {'query': 'p(x',
+                'action_policy': self.action_policy['name'],
+                'sequence': 'q(1)'}
+        check_err({}, context, helper.FakeRequest(body),
+                  'Parse failure')
+
+        # Multiple querys
+        body = {'query': 'p(x) q(x)',
+                'action_policy': self.action_policy['name'],
+                'sequence': 'q(1)'}
+        check_err({}, context, helper.FakeRequest(body),
+                  'more than 1 rule')
+
+        # Missing action_policy
+        body = {'query': 'p(x)',
+                'sequence': 'q(1)'}
+        check_err({}, context, helper.FakeRequest(body),
+                  'Simulate requires parameters')
+
+        # Missing sequence
+        body = {'query': 'p(x)',
+                'action_policy': self.action_policy['name']}
+        check_err({}, context, helper.FakeRequest(body),
+                  'Simulate requires parameters')
+
+        # Syntactically invalid sequence
+        body = {'query': 'p(x)',
+                'action_policy': self.action_policy['name'],
+                'sequence': 'q(1'}
+        check_err({}, context, helper.FakeRequest(body),
+                  'Parse failure')
+
+        # Semantically invalid sequence
+        body = {'query': 'p(x)',
+                'action_policy': self.action_policy['name'],
+                'sequence': 'r(1)'}  # r is not an action
+        check_err({}, context, helper.FakeRequest(body),
+                  'non-action, non-update')
+
+    def test_policy_api_model_error(self):
+        """Test the policy api model."""
+
+        # add policy without name
+        self.assertRaises(webservice.DataModelException,
+                          self.policy_model.add_item, {}, {})
+
+        # add policy with bad ID
+        self.assertRaises(webservice.DataModelException,
+                          self.policy_model.add_item, {'name': '7*7'}, {})
+        self.assertRaises(webservice.DataModelException,
+                          self.policy_model.add_item,
+                          {'name': 'p(x) :- q(x)'}, {})
+
+        # add policy with invalid 'kind'
+        self.assertRaises(webservice.DataModelException,
+                          self.policy_model.add_item,
+                          {'kind': 'nonexistent', 'name': 'alice'}, {})
+
+        # add existing policy
+        self.policy_model.add_item({'name': 'Test1'}, {})
+        self.assertRaises(KeyError, self.policy_model.add_item,
+                          {'name': 'Test1'}, {})
+
+        # delete non-existent policy
+        self.assertRaises(KeyError, self.policy_model.delete_item,
+                          'noexist', {})
+
+        # delete system-maintained policy
+        policies = self.policy_model.get_items({})['results']
+        class_policy = [p for p in policies if p['name'] == 'classification']
+        class_policy = class_policy[0]
+        self.assertRaises(KeyError, self.policy_model.delete_item,
+                          class_policy['id'], {})
