@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # Copyright (c) 2015 Hewlett-Packard. All rights reserved.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,6 +12,10 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
 import mock
 
 # mocking muranoclient so that python-muranoclient
@@ -273,7 +276,7 @@ class TestMuranoDriver(base.TestCase):
                                       '769af50c-9629-4694-b623-e9b392941279',
                                       'restartVM']}
         self.driver.execute(action, action_args)
-        self.assertTrue(action_response in self.driver.action_call_returns)
+        self.assertIn(action_response, self.driver.action_call_returns)
 
 
 # Sample responses from murano-client
