@@ -12,9 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from oslo_log import log as logging
-import retrying
 
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+
+import tenacity
+
+from oslo_config import cfg
+from oslo_log import log as logging
+
+from congress.api import base as api_base
 from congress.datalog import base
 from congress.datalog import compile
 from congress import harness
@@ -34,11 +42,11 @@ class TestRuntimePerformance(testbase.TestCase):
 
     To run one test:
       nosetests -v  \
-      congress/tests/policy/test_runtime_performance.py:TestRuntimePerformance.test_foo
+      congress/tests/policy_engines/test_agnostic_performance.py:TestRuntimePerformance.test_foo
 
     To collect profiling data:
       python -m cProfile -o profile.out `which nosetests` -v \
-      congress/tests/policy/test_runtime_performance.py:TestRuntimePerformance.test_foo
+      congress/tests/policy_engines/test_agnostic_performance.py:TestRuntimePerformance.test_foo
 
     To parse and sort profiling data in different ways:
       import pstats
@@ -152,7 +160,7 @@ class TestRuntimePerformance(testbase.TestCase):
     def test_simulate_latency(self):
         # We think the cost will be the sum of the simulate call + the cost to
         # do and undo the evaluation, so this test should focus on the cost
-        # specific to the simulate call, so the the test should do a minimal
+        # specific to the simulate call, so the test should do a minimal
         # amount of evaluation.
 
         MAX = 10
@@ -186,7 +194,12 @@ class TestDsePerformance(testbase.SqlTestCase):
 
     def setUp(self):
         super(TestDsePerformance, self).setUp()
-        self.cage = harness.create(helper.root_path(), config_override={})
+        cfg.CONF.set_override(
+            'drivers',
+            [('congress.tests.datasources.performance_datasource_driver'
+              '.PerformanceTestDriver')])
+        self.cage = helper.make_dsenode_new_partition("perf")
+        harness.create2(existing_node=self.cage)
         self.api = {'policy': self.cage.service_object('api-policy'),
                     'rule': self.cage.service_object('api-rule'),
                     'table': self.cage.service_object('api-table'),
@@ -194,9 +207,9 @@ class TestDsePerformance(testbase.SqlTestCase):
                     'datasource': self.cage.service_object('api-datasource'),
                     'status': self.cage.service_object('api-status'),
                     'schema': self.cage.service_object('api-schema')}
-        self.engine = self.cage.service_object('engine')
+        self.engine = self.cage.service_object(api_base.ENGINE_SERVICE_ID)
 
-    @retrying.retry(wait_fixed=100)
+    @tenacity.retry(wait=tenacity.wait_fixed(0.1))
     def wait_til_query_nonempty(self, query, policy):
         if len(self.engine.select(query, target=policy)) == 0:
             raise Exception("Query %s is not empty" % query)
@@ -211,15 +224,12 @@ class TestDsePerformance(testbase.SqlTestCase):
         """
         MAX_TUPLES = 700
         # install datasource driver we can control
-        self.cage.loadModule(
-            "TestDriver",
-            helper.data_module_path(
-                "../tests/datasources/test_driver.py"))
-        self.cage.createservice(
-            name="data",
-            moduleName="TestDriver",
-            args=helper.datasource_openstack_args())
-        driver = self.cage.service_object('data')
+        kwds = {}
+        kwds['name'] = 'data'
+        kwds['args'] = helper.datasource_openstack_args()
+        kwds['driver'] = 'performance'
+        driver = self.cage.create_datasource_service(kwds)
+        self.cage.register_service(driver)
         driver.poll_time = 0
         self.engine.create_policy('data')
 
@@ -232,8 +242,8 @@ class TestDsePerformance(testbase.SqlTestCase):
         policy = self.engine.DEFAULT_THEORY
         formula = compile.parse1(
             'q(1) :- data:p(1, 2.3, "foo", "bar", 1, %s)' % ('a'*100 + '1'))
-        self.api['rule'].publish(
-            'policy-update', [compile.Event(formula, target=policy)])
+        self.engine.process_policy_update(
+            [compile.Event(formula, target=policy)])
 
         # Poll data and wait til it arrives at engine
         driver.poll()
@@ -251,15 +261,12 @@ class TestDsePerformance(testbase.SqlTestCase):
         """
         MAX_TUPLES = 700
         # install datasource driver we can control
-        self.cage.loadModule(
-            "PerformanceTestDriver",
-            helper.data_module_path(
-                "../tests/datasources/performance_datasource_driver.py"))
-        self.cage.createservice(
-            name="data",
-            moduleName="PerformanceTestDriver",
-            args=helper.datasource_openstack_args())
-        driver = self.cage.service_object('data')
+        kwds = {}
+        kwds['name'] = 'data'
+        kwds['args'] = helper.datasource_openstack_args()
+        kwds['driver'] = 'performance'
+        driver = self.cage.create_datasource_service(kwds)
+        self.cage.register_service(driver)
         driver.poll_time = 0
         self.engine.create_policy('data')
 
@@ -278,8 +285,8 @@ class TestDsePerformance(testbase.SqlTestCase):
         formula = compile.parse1(
             'q(1) :- data:p(1, 2.3, "foo", "bar", 1, %s)' % ('a'*100 + '1'))
         LOG.info("publishing rule")
-        self.api['rule'].publish(
-            'policy-update', [compile.Event(formula, target=policy)])
+        self.engine.process_policy_update(
+            [compile.Event(formula, target=policy)])
 
         # Poll data and wait til it arrives at engine
         driver.poll()
