@@ -16,7 +16,6 @@
 from oslo_log import log as logging
 from tempest import clients
 from tempest import config
-from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions
 from tempest import test
 
@@ -33,7 +32,7 @@ class TestKeystoneV2Driver(manager_congress.ScenarioPolicyBase):
         super(TestKeystoneV2Driver, cls).skip_checks()
         if not (CONF.network.project_networks_reachable or
                 CONF.network.public_network_id):
-            msg = ('Either project_networks_reachable must be "true", or'
+            msg = ('Either project_networks_reachable must be "true", or '
                    'public_network_id must be defined.')
             cls.enabled = False
             raise cls.skipException(msg)
@@ -85,9 +84,8 @@ class TestKeystoneV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(
-                func=_check_data_table_keystone_users,
-                duration=100, sleep_for=4):
+        if not test.call_until_true(func=_check_data_table_keystone_users,
+                                    duration=100, sleep_for=4):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -121,9 +119,8 @@ class TestKeystoneV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(
-                func=_check_data_table_keystone_roles,
-                duration=100, sleep_for=4):
+        if not test.call_until_true(func=_check_data_table_keystone_roles,
+                                    duration=100, sleep_for=4):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -157,16 +154,7 @@ class TestKeystoneV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(
-                func=_check_data_table_keystone_tenants,
-                duration=100, sleep_for=5):
+        if not test.call_until_true(func=_check_data_table_keystone_tenants,
+                                    duration=100, sleep_for=5):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
-
-    @test.attr(type='smoke')
-    def test_update_no_error(self):
-        if not test_utils.call_until_true(
-                func=lambda: self.check_datasource_no_error('keystone'),
-                duration=30, sleep_for=5):
-            raise exceptions.TimeoutException('Datasource could not poll '
-                                              'without error.')
