@@ -17,7 +17,6 @@ import time
 from oslo_log import log as logging
 from tempest import clients
 from tempest import config
-from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions
 from tempest import test
 
@@ -84,8 +83,8 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -161,8 +160,8 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                             return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -256,8 +255,8 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                             return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -310,8 +309,8 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -347,8 +346,8 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
 
@@ -385,15 +384,7 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                         return False
             return True
 
-        if not test_utils.call_until_true(func=_check_data,
-                                          duration=200, sleep_for=10):
+        if not test.call_until_true(func=_check_data,
+                                    duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
-
-    @test.attr(type='smoke')
-    def test_update_no_error(self):
-        if not test_utils.call_until_true(
-                func=lambda: self.check_datasource_no_error('neutronv2'),
-                duration=30, sleep_for=5):
-            raise exceptions.TimeoutException('Datasource could not poll '
-                                              'without error.')
