@@ -20,13 +20,12 @@ from oslo_log import log as logging
 from tempest.common import credentials_factory as credentials
 from tempest import config
 from tempest.lib.common.utils import data_utils
-from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions
 from tempest import manager as tempestmanager
+from tempest.scenario import manager
+from tempest import test
 
 from congress_tempest_tests.services.policy import policy_client
-# use local copy of tempest scenario manager during upstream refactoring
-from congress_tempest_tests.tests.scenario import manager
 
 CONF = config.CONF
 LOG = logging.getLogger(__name__)
@@ -51,18 +50,32 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
         # auth provider for admin credentials
         creds = credentials.get_configured_admin_credentials('identity_admin')
         auth_prov = tempestmanager.get_auth_provider(creds)
+        cls.setup_required_clients(auth_prov)
 
+    @classmethod
+    def setup_required_clients(cls, auth_prov):
+        # Get congress client
         cls.admin_manager.congress_client = policy_client.PolicyClient(
             auth_prov, "policy", CONF.identity.region)
 
+        # Get telemtery_client
         if getattr(CONF.service_available, 'ceilometer', False):
             import ceilometer.tests.tempest.service.client as telemetry_client
             cls.admin_manager.telemetry_client = (
                 telemetry_client.TelemetryClient(
-                    auth_prov, CONF.telemetry.catalog_type,
-                    CONF.identity.region,
+                    auth_prov,
+                    CONF.telemetry.catalog_type, CONF.identity.region,
                     endpoint_type=CONF.telemetry.endpoint_type))
 
+        # Get alarms client
+        if getattr(CONF.service_available, 'aodh_plugin', False):
+            import aodh.tests.tempest.service.client as alarms_client
+            cls.admin_manager.alarms_client = (
+                alarms_client.AlarmingClient(
+                    auth_prov,
+                    CONF.alarming_plugin.catalog_type, CONF.identity.region,
+                    CONF.alarming_plugin.endpoint_type))
+
     def _setup_network_and_servers(self):
         self.security_group = self._create_security_group()
         self.network, self.subnet, self.router = self.create_networks()
@@ -82,41 +95,28 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
         checking the result of list_[networks,routers,subnets].
         """
 
-        seen_nets = self.admin_manager.networks_client.list_networks()
-        seen_names = [n['name'] for n in seen_nets['networks']]
-        seen_ids = [n['id'] for n in seen_nets['networks']]
+        seen_nets = self._list_networks()
+        seen_names = [n['name'] for n in seen_nets]
+        seen_ids = [n['id'] for n in seen_nets]
         self.assertIn(self.network['name'], seen_names)
         self.assertIn(self.network['id'], seen_ids)
 
         if self.subnet:
-            seen_subnets = self.admin_manager.subnets_client.list_subnets()
-            seen_net_ids = [n['network_id'] for n in seen_subnets['subnets']]
-            seen_subnet_ids = [n['id'] for n in seen_subnets['subnets']]
+            seen_subnets = self._list_subnets()
+            seen_net_ids = [n['network_id'] for n in seen_subnets]
+            seen_subnet_ids = [n['id'] for n in seen_subnets]
             self.assertIn(self.network['id'], seen_net_ids)
             self.assertIn(self.subnet['id'], seen_subnet_ids)
 
         if self.router:
-            seen_routers = self.admin_manager.routers_client.list_routers()
-            seen_router_ids = [n['id'] for n in seen_routers['routers']]
-            seen_router_names = [n['name'] for n in seen_routers['routers']]
+            seen_routers = self._list_routers()
+            seen_router_ids = [n['id'] for n in seen_routers]
+            seen_router_names = [n['name'] for n in seen_routers]
             self.assertIn(self.router['name'],
                           seen_router_names)
             self.assertIn(self.router['id'],
                           seen_router_ids)
 
-    def check_datasource_no_error(self, datasource_name):
-        """Check that datasource has no error on latest update"""
-        ds_status = self.admin_manager.congress_client.list_datasource_status(
-            datasource_name)
-        if (ds_status['initialized'] == 'True' and
-           ds_status['number_of_updates'] != '0' and
-           ds_status['last_error'] == 'None'):
-            return True
-        else:
-            LOG.debug('datasource %s not initialized, not polled, or shows '
-                      'error. Full status: %s', datasource_name, ds_status)
-            return False
-
     def _create_server(self, name, network):
         keypair = self.create_keypair()
         self.keypairs[keypair['name']] = keypair
@@ -191,8 +191,7 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
                                             private_key=private_key)
         old_nic_list = self._get_server_nics(ssh_client)
         # get a port from a list of one item
-        port_list = self.admin_manager.ports_client.list_ports(
-            device_id=server['id'])['ports']
+        port_list = self._list_ports(device_id=server['id'])
         self.assertEqual(1, len(port_list))
         old_port = port_list[0]
         _, interface = self.interface_client.create_interface(
@@ -205,14 +204,13 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
                         server['id'], interface['port_id'])
 
         def check_ports():
-            ports = self.admin_manager.ports_client.list_ports(
-                device_id=server['id'])['ports']
-            self.new_port_list = [port for port in ports if port != old_port]
+            self.new_port_list = [port for port in
+                                  self._list_ports(device_id=server['id'])
+                                  if port != old_port]
             return len(self.new_port_list) == 1
 
-        if not test_utils.call_until_true(check_ports,
-                                          CONF.network.build_timeout,
-                                          CONF.network.build_interval):
+        if not test.call_until_true(check_ports, CONF.network.build_timeout,
+                                    CONF.network.build_interval):
             raise exceptions.TimeoutException("No new port attached to the "
                                               "server in time (%s sec) !"
                                               % CONF.network.build_timeout)
@@ -223,18 +221,15 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
             self.diff_list = [n for n in new_nic_list if n not in old_nic_list]
             return len(self.diff_list) == 1
 
-        if not test_utils.call_until_true(check_new_nic,
-                                          CONF.network.build_timeout,
-                                          CONF.network.build_interval):
+        if not test.call_until_true(check_new_nic, CONF.network.build_timeout,
+                                    CONF.network.build_interval):
             raise exceptions.TimeoutException("Interface not visible on the "
                                               "guest after %s sec"
                                               % CONF.network.build_timeout)
 
         num, new_nic = self.diff_list[0]
-        ssh_client.assign_static_ip(
-            nic=new_nic,
-            addr=new_port.fixed_ips[0]['ip_address'],
-            network_mask_bits=CONF.network.project_network_mask_bits)
+        ssh_client.assign_static_ip(nic=new_nic,
+                                    addr=new_port.fixed_ips[0]['ip_address'])
         ssh_client.turn_nic_on(nic=new_nic)
 
     def _get_server_nics(self, ssh_client):
@@ -251,10 +246,9 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
         floating_ip, server = self.floating_ip_tuple
         # get internal ports' ips:
         # get all network ports in the new network
-        ports = self.admin_manager.ports_client.list_ports(
-            tenant_id=server['tenant_id'], network_id=network.id)['ports']
-
-        internal_ips = (p['fixed_ips'][0]['ip_address'] for p in ports
+        internal_ips = (p['fixed_ips'][0]['ip_address'] for p in
+                        self._list_ports(tenant_id=server['tenant_id'],
+                                         network_id=network.id)
                         if p['device_owner'].startswith('network'))
 
         self._check_server_connectivity(floating_ip, internal_ips)
@@ -266,8 +260,8 @@ class ScenarioPolicyBase(manager.NetworkScenarioTest):
             LOG.info(msg)
             return
 
-        subnet = self.admin_manager.subnets_client.list_subnets(
-            network_id=CONF.network.public_network_id)['subnets']
+        subnet = self._list_subnets(
+            network_id=CONF.network.public_network_id)
         self.assertEqual(1, len(subnet), "Found %d subnets" % len(subnet))
 
         external_ips = [subnet[0]['gateway_ip']]
